<?php

namespace Drupal\access_policy;

/**
 * Defines an access rule execution context class.
 *
 * Contexts can change for different access rules. For example, some access
 * rules only need the user entity while others need both entity and user
 * entity.
 */
class AccessRuleExecutionContext {

  /**
   * The current operation.
   *
   * @var string
   */
  protected $operation;

  /**
   * The current context array.
   *
   * @var array
   */
  protected $context = [];

  /**
   * Constructs a new AccessRuleExecutionContext object.
   *
   * @param string $operation
   *   The current operation.
   * @param array $context
   *   The context array.
   */
  public function __construct($operation, array $context) {
    $this->operation = $operation;
    $this->context = $context;
  }

  /**
   * Create the execution context.
   *
   * @param string $operation
   *   The current operation.
   * @param array $context
   *   The context array.
   *
   * @return static
   *   The AccessRuleExecutionContext object.
   */
  public static function create($operation, array $context) {
    return new static($operation, $context);
  }

  /**
   * Get the current operation.
   *
   * @return string
   *   The current operation (e.g view, update, delete etc.)
   */
  public function getOperation() {
    return $this->operation;
  }

  /**
   * Get a specific context value.
   *
   * @param string $key
   *   The context key.
   *
   * @return mixed
   *   The execution context value.
   */
  public function get($key) {
    if (isset($this->context[$key])) {
      return $this->context[$key];
    }
    return NULL;
  }

}
